from django.http import HttpResponseBadRequest, JsonResponse
from django.views import View

from core.models import Assembly

from backoffice.views.mixins import ConferenceLoginRequiredMixin


def flip_coordinates(coordinates):
    """Flips the coordinates' tuples' items as latitude/longitude in GeoJSON represents to Y/X instead of X/Y."""
    result = []
    for polygon in coordinates:
        p = []
        for coord in polygon:
            p.append((coord[1], coord[0]))
        result.append(p)
    return result


class AssemblyGeoJsonExportView(ConferenceLoginRequiredMixin, View):
    def get(self, request):
        floor = request.GET.get('floor')
        if floor is None:
            return HttpResponseBadRequest('Missing "floor" parameter.')

        features = []

        qs = Assembly.objects.conference_accessible(self.conference, self.conferencemember).filter(location_floor__index=floor)
        qs = qs.exclude(location_data__point=None, location_data__boundaries=None)

        for assembly in qs:
            if coords := assembly.location_data.get('boundaries'):
                feature = {
                    'type': 'Feature',
                    'geometry': {
                        'type': 'Polygon',
                        'coordinates': flip_coordinates(coords),
                    },
                    'properties': {
                        'name': assembly.name,
                        'slug': assembly.slug,
                        'published': assembly.is_placed,
                    },
                }
                features.append(feature)

        result = {
            'type': 'FeatureCollection',
            'features': features,
        }
        return JsonResponse(result, content_type='application/vnd.geo+json', json_dumps_params={'indent': 2})
