import logging
import re

from django.shortcuts import render
from django.views.generic import TemplateView

from backoffice.views.moderation.assemblies import ModerationAssemblyDetailView, ModerationAssemblyListView
from backoffice.views.moderation.badges import ModerationBadgeDetailView, ModerationBadgeListView
from backoffice.views.moderation.board_entry import ModerationBoardDetailView, ModerationBoardListView
from backoffice.views.moderation.events import ModerationEventDetailView, ModerationEventListView
from backoffice.views.moderation.mixins import ModerationAdminMixin, lookup_moderation_items
from backoffice.views.moderation.projects import ModerationProjectDetailView, ModerationProjectListView
from backoffice.views.moderation.users import ModerationUserDetailView, ModerationUserListView, ModerationUserRenameView
from backoffice.views.moderation.wiki import ModerationWikiDetailView, ModerationWikiListView

logger = logging.getLogger(__name__)


RE_UUID = re.compile(r'[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}')


class IndexView(ModerationAdminMixin, TemplateView):
    template_name = 'backoffice/moderation_index.html'

    def get(self, request, *args, **kwargs):
        ctx = self.get_context_data()
        ctx['results'] = results = {}

        if q := request.GET.get('q'):
            ctx['query'] = q
            results.update(lookup_moderation_items(self.conference, q.strip()))

        return render(request, self.get_template_names(), ctx)


__all__ = [
    'IndexView',
    'ModerationAdminMixin',
    'ModerationAssemblyDetailView',
    'ModerationAssemblyListView',
    'ModerationBadgeDetailView',
    'ModerationBadgeListView',
    'ModerationBoardDetailView',
    'ModerationBoardListView',
    'ModerationEventDetailView',
    'ModerationEventListView',
    'ModerationProjectDetailView',
    'ModerationProjectListView',
    'ModerationUserDetailView',
    'ModerationUserListView',
    'ModerationUserRenameView',
    'ModerationWikiDetailView',
    'ModerationWikiListView',
]
