import logging

from django.contrib import messages
from django.shortcuts import redirect
from django.views.generic import DetailView, ListView

from backoffice.views.moderation.mixins import ModerationAdminMixin

logger = logging.getLogger(__name__)


class ModerationBoardListView(ModerationAdminMixin, ListView):
    template_name = 'backoffice/moderation_board-list.html'

    def get_queryset(self):
        qs = self.conference.bulletin_board_entries.all()
        return qs


class ModerationBoardDetailView(ModerationAdminMixin, DetailView):
    template_name = 'backoffice/moderation_board-detail.html'

    def get_queryset(self):
        qs = self.conference.bulletin_board_entries.all()
        return qs

    def post(self, request, *args, **kwargs):
        current_object = self.get_object()
        action = request.POST.get('action')

        # TODO: add log entries
        if action == 'hide':
            current_object.hidden = True
            current_object.save(update_fields=['hidden'])
            messages.success(request, f'board entry forced hidden: #{current_object.id}')

        elif action == 'show':
            current_object.hidden = False
            current_object.save(update_fields=['hidden'])
            messages.success(request, f'board entry is not forced hidden any more: #{current_object.id}')

        elif action == 'delete':
            current_object.delete()
            messages.success(request, f'board entry deleted: #{current_object.id}')
            return redirect('backoffice:moderation-board-list')

        else:
            messages.error(request, f'UNKNOWN ACTION: {action}')

        return redirect('backoffice:moderation-board-detail', pk=current_object.pk)
