import logging
from typing import Any

from django.http import HttpRequest, HttpResponse
from django.views.generic import CreateView, UpdateView

from core.models.projects import Project

from backoffice.views.mixins import AssemblyMixin
from backoffice.views.projects.mixins import AssemblyProjectFormMixin, ProjectListViewMixin

logger = logging.getLogger(__name__)


class AssemblyProjectListView(AssemblyMixin, ProjectListViewMixin):
    assembly_url_param = 'assembly'

    def get_queryset(self):
        return Project.objects.manageable_by_user(self.conference, user=self.request.user).filter(assembly=self.assembly)

    def get_context_data(self, **kwargs):
        return {
            **super().get_context_data(**kwargs),
            'assembly': self.assembly,
        }


class AssemblyProjectCreateView(AssemblyProjectFormMixin, CreateView):
    def post(self, request: HttpRequest, *args: str, **kwargs: Any) -> HttpResponse:
        self.object = None
        return super().post(request, *args, **kwargs)


class AssemblyProjectUpdateView(AssemblyProjectFormMixin, UpdateView):
    def post(self, request: HttpRequest, *args: str, **kwargs: Any) -> HttpResponse:
        self.object = self.get_object()
        return super().post(request, *args, **kwargs)
