# Hand-Crafted (with some help by Django 3.1.3) on 2020-11-28 11:00

from django.conf import settings
from django.db import migrations, models

import core.fields
import core.storages


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0018_schema_extensions_data'),
    ]

    operations = [
        # rename the models
        migrations.RenameModel(old_name='Venue', new_name='Assembly'),
        migrations.RenameModel(old_name='VenueLink', new_name='AssemblyLink'),
        migrations.RenameModel(old_name='VenueMember', new_name='AssemblyMember'),

        # rename all affected fields
        migrations.RenameField(model_name='assembly', old_name='venue_type', new_name='assembly_type'),
        migrations.RenameField(model_name='assembly', old_name='venue_location', new_name='assembly_location'),
        migrations.RenameField(model_name='assembly', old_name='venue_link', new_name='assembly_link'),
        migrations.RenameField(model_name='assemblymember', old_name='venue', new_name='assembly'),
        migrations.RenameField(model_name='badge', old_name='issuing_venue', new_name='issuing_assembly'),
        migrations.RenameField(model_name='event', old_name='venue', new_name='assembly'),
        migrations.RenameField(model_name='room', old_name='venue', new_name='assembly'),

        # rename the conference+slug constraint
        migrations.RemoveConstraint(model_name='assembly', name='unique_conferencevenue_slug'),
        migrations.AddConstraint(model_name='assembly', constraint=models.UniqueConstraint(fields=('conference', 'slug'), name='unique_conferenceassembly_slug')),

        # set Event.assembly non-nullable
        migrations.AlterField(
            model_name='event',
            name='assembly',
            field=models.ForeignKey(on_delete=models.deletion.PROTECT, related_name='events', to='core.assembly'),
        ),

        # to make Django Migration Manager happy, adjust all help_text and verbose_name translation strings to the new values
        migrations.AlterModelOptions(
            name='assembly',
            options={'verbose_name': 'Assembly', 'verbose_name_plural': 'Assemblys'},
        ),
        migrations.AlterField(
            model_name='assembly',
            name='assembly_link',
            field=models.URLField(blank=True, help_text='Assembly__link__help', null=True, verbose_name='Assembly__link'),
        ),
        migrations.AlterField(
            model_name='assembly',
            name='assembly_location',
            field=models.TextField(blank=True, help_text='Assembly__location__help', null=True, verbose_name='Assembly__location'),
        ),
        migrations.AlterField(
            model_name='assembly',
            name='assembly_type',
            field=models.CharField(choices=[('virtual', 'Assembly__type-virtual'), ('physical', 'Assembly__type-physical')], help_text='Assembly__type__help', max_length=20, verbose_name='Assembly__type'),
        ),
        migrations.AlterField(
            model_name='assembly',
            name='banner_image',
            field=models.ImageField(blank=True, height_field='banner_image_height', help_text='Assembly__banner_image__help', null=True, storage=core.storages.select_storage, upload_to='', verbose_name='Assembly__banner_image', width_field='banner_image_width'),
        ),
        migrations.AlterField(
            model_name='assembly',
            name='conference',
            field=core.fields.ConferenceReference(help_text='Conference__reference_help', on_delete=models.deletion.CASCADE, related_name='assemblies', to='core.conference', verbose_name='Conference__reference'),
        ),
        migrations.AlterField(
            model_name='assembly',
            name='description',
            field=models.TextField(blank=True, help_text='Assembly__description__help', null=True, verbose_name='Assembly__description'),
        ),
        migrations.AlterField(
            model_name='assembly',
            name='favorited_by',
            field=models.ManyToManyField(help_text='Assembly__favorited_by__help', related_name='favorite_assemblies', to=settings.AUTH_USER_MODEL, verbose_name='Assembly__favorited_by'),
        ),
        migrations.AlterField(
            model_name='assembly',
            name='hierarchy',
            field=models.CharField(choices=[('regular', 'Assembly__hierarchy-regular'), ('cluster', 'Assembly__hierarchy-cluster'), ('clusterrestricted', 'Assembly__hierarchy-clusterrestricted')], default='regular', help_text='Assembly__hierarchy__help', max_length=20, verbose_name='Assembly__hierarchy'),
        ),
        migrations.AlterField(
            model_name='assembly',
            name='internal_comment',
            field=models.TextField(blank=True, help_text='Assembly__internal_comment__help', null=True, verbose_name='Assembly__internal_comment'),
        ),
        migrations.AlterField(
            model_name='assembly',
            name='is_official',
            field=models.BooleanField(default=False, help_text='Assembly__is_official__help', verbose_name='Assembly__is_official'),
        ),
        migrations.AlterField(
            model_name='assembly',
            name='name',
            field=models.CharField(help_text='Assembly__name__help', max_length=200, verbose_name='Assembly__name'),
        ),
        migrations.AlterField(
            model_name='assembly',
            name='parent',
            field=models.ForeignKey(blank=True, help_text='Assembly__parent__help', null=True, on_delete=models.deletion.PROTECT, related_name='+', to='core.assembly', verbose_name='Assembly__parent'),
        ),
        migrations.AlterField(
            model_name='assembly',
            name='registration_details',
            field=models.TextField(blank=True, help_text='Assembly__registration_details__help', null=True, verbose_name='Assembly__registration_details'),
        ),
        migrations.AlterField(
            model_name='assembly',
            name='slug',
            field=models.SlugField(help_text='Assembly__slug__help', verbose_name='Assembly__slug'),
        ),
        migrations.AlterField(
            model_name='assembly',
            name='state',
            field=models.CharField(choices=[('planned', 'Assembly__state-planned'), ('registered', 'Assembly__state-registered'), ('hidden', 'Assembly__state-hidden'), ('accepted', 'Assembly__state-accepted'), ('rejected', 'Assembly__state-rejected'), ('placed', 'Assembly__state-placed'), ('arrived', 'Assembly__state-arrived_self'), ('confirmed', 'Assembly__state-arrived_confirmed')], default='planned', help_text='Assembly__state__help', max_length=20, verbose_name='Assembly__state'),
        ),
        migrations.AlterField(
            model_name='assemblylink',
            name='is_public',
            field=models.BooleanField(default=False, help_text='AssemblyLink__is_public__help', verbose_name='AssemblyLink__is_public'),
        ),
        migrations.AlterField(
            model_name='assemblylink',
            name='type',
            field=models.CharField(choices=[('related', 'AssemblyLink__type-related'), ('associated', 'AssemblyLink__type-associated'), ('other', 'AssemblyLink__type-other')], default='related', max_length=20),
        ),
        migrations.AlterField(
            model_name='assemblymember',
            name='role',
            field=models.CharField(choices=[('official', 'AssemblyMember__role-official'), ('manager', 'AssemblyMember__role-manager'), ('regular', 'AssemblyMember__role-regular'), ('guest', 'AssemblyMember__role-guest'), ('blocked', 'AssemblyMember__role-blocked')], default='regular', help_text='AssemblyMember__role__help', max_length=20, verbose_name='AssemblyMember__role'),
        ),
        migrations.AlterField(
            model_name='assemblymember',
            name='show_public',
            field=models.BooleanField(default=True, help_text='AssemblyMember__show_public__help', verbose_name='AssemblyMember__show_public'),
        ),
    ]
