from django.conf import settings
from django.db import models

from core.fields import ConferenceReference
from core.markdown import compile_translated_markdown_fields, store_relationships


class BulletinBoardEntry(models.Model):
    conference = ConferenceReference(related_name='bulletin_board_entries')
    owner = models.ForeignKey(settings.AUTH_USER_MODEL, related_name='bulletin_board_entries', on_delete=models.CASCADE)
    timestamp = models.DateTimeField(auto_now_add=True)
    is_public = models.BooleanField(default=True)
    hidden = models.BooleanField(default=False)
    title = models.CharField(max_length=200)
    text = models.TextField()
    text_html = models.TextField()

    def __str__(self):
        return f'{self.title} by {self.owner})'

    def save(self, *args, update_fields=None, **kwargs):
        if not self.pk:
            super().save(*args, update_fields=update_fields, **kwargs)

        if update_fields is None or 'text' in update_fields:
            render_results = compile_translated_markdown_fields(self, self.conference, 'text')
            store_relationships(self.conference, self, render_results)
        super().save(*args, update_fields=update_fields, **kwargs)
